@@ -10,6 +10,6 @@ import django.dispatch
 
 
 # Arguments:"previous_parent"
-forum_moved = django.dispatch.Signal(providing_args=["previous_parent", ])
+forum_moved = django.dispatch.Signal()
 # Arguments:"forum", "user", "request", "response"
-forum_viewed = django.dispatch.Signal(providing_args=["forum", "user", "request", "response", ])
+forum_viewed = django.dispatch.Signal()
